local L = Capitalist.Locale
local realm = GetRealmName()
local character = UnitName("player")

local idEnchantingVellum = 38682

local componentsMemory = { }

function Capitalist:ComponentMemoryReset()
	componentsMemory = { }
end

local function IsNorthrendComponent(itemId)
	-- REVIEW: hardcoded item ID values
	return ((itemId >= 34052) and (itemId <= 34057))
end
local function IsBurningCrusadeComponent(itemId)
	-- REVIEW: hardcoded item ID values
	return ((itemId >= 22445) and (itemId <= 22450))
end
local function IsClassicComponent(itemName)
	-- REVIEW: substring test
	local lastWord = itemName:match("[%a ]+ (%a+)")
	return ((lastWord == L["Dust"]) or (lastWord == L["Essence"]) or (lastWord == L["Shard"]) or (lastWord == L["Crystal"]))
end

function Capitalist:GetComponentId(componentName)
	if (componentName == L["Enchanting Vellum"]) then
		return idEnchantingVellum
	else
		return self.db.profile.components[componentName].id
	end
end

function Capitalist:GetComponentPrice(componentName)
	if (self.db.profile.components and
		self.db.profile.components[componentName] and
		self.db.profile.components[componentName].price) then
		return self.db.profile.components[componentName].price
	else
		return self.componentPriceDefault
	end
end

function Capitalist:IsComponentAllowed(componentName)
	local allowed = true
	
	local itemId = self:GetComponentId(componentName)

	-- TODO: enchanting-specific
	if (IsNorthrendComponent(itemId)) then
		allowed = self.db.profile.filters.global.Northrend
	elseif (IsBurningCrusadeComponent(itemId)) then
		allowed = self.db.profile.filters.global.BurningCrusade
	elseif (IsClassicComponent(componentName)) then
		allowed = self.db.profile.filters.global.Classic
	else
		-- Unidentified components left alone (allowed)
	end	

	return allowed
end

function Capitalist:ComponentIsVisible(componentName)
	return componentsMemory[componentName] ~= nil
end

function Capitalist:ComponentSetVisible(componentName, visible)
	if (visible) then
		componentsMemory[componentName] = { }
	else
		componentsMemory[componentName] = nil
	end
end

function Capitalist:GetVisibleComponents()
	componentList = {}
	for componentName, componentData in pairs(componentsMemory) do
		table.insert(componentList, componentName)
	end
	return componentList
end
